pub enum GraphError {
ClientTypeError(String),
LabelNotFound,
RelationshipTypeNotFound,
PropertyKeyNotFound,
InvalidUtf8,
}Expand description
Common error type for this crate.
Variants
ClientTypeError(String)
Returned if the data you requested is of a different type than the data returned by the database.
LabelNotFound
Returned if a label name was not found in the graph’s internal registry.
This error is taken care of by the implementation and should never reach your code.
RelationshipTypeNotFound
Returned if a relationship type name was not found in the graph’s internal registry.
This error is taken care of by the implementation and should never reach your code.
PropertyKeyNotFound
Returned if a property key name was not found in the graph’s internal registry.
This error is taken care of by the implementation and should never reach your code.
InvalidUtf8
Returned if you requested a String and the database responded with bytes that are invalid UTF-8.
If you don’t care about whether the data is valid UTF-8, consider requesting a RedisString instead.